;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "js-comint" "20250807.352"
  "JavaScript interpreter in window."
  '((emacs "28.1"))
  :url "https://github.com/redguardtoo/js-comint"
  :commit "41015e29c8f51f7a927b453d97e14bc0cd7054de"
  :revdesc "41015e29c8f5"
  :keywords '("javascript" "node" "inferior-mode" "convenience")
  :authors '(("Paul Huff" . "paul.huff@gmail.com")
             ("Stefano Mazzucco" . "MYFIRSTNAME-AT-CURSO-DOT-RE"))
  :maintainers '(("Chen Bin" . "chenbin.shATgmailDOTcom")))
